Code Signing Policy
===================

PyJibe uses free code signing provided by `SignPath.io <https://about.signpath.io/>`_,
certificate by `SignPath Foundation <https://signpath.org/>`_. These binaries
can be downloaded from the `release page <https://github.com/AFM-analysis/PyJibe/releases>`_.


Project Integrity
-----------------

To verify the integrity of PyJibe, we manage access to the PyJibe repository
via GitHub Team roles:

- **Triage**: The `Members team of AFM-analysis <https://github.com/orgs/AFM-analysis/teams/members>`_
  has permission to triage (e.g. modify issues).
- **Core**: The `Core team of AFM-analysis <https://github.com/orgs/AFM-analysis/teams/core>`_
  consists of people who are trusted to modify the source code in the project's
  version control system without additional reviews.
- There is no special role for *Commiters*. External contributors or members
  of the *Triage* team must create a pull request which is reviewed by a
  *Core* team member.
- Furthermore, we enforce 2FA for every member of the AFM-Analysis GitHub
  organization.


Privacy Policy
--------------
This program will not transfer any information to other networked systems
unless specifically requested by the user or the person installing
or operating it.

Specifically, PyJibe does not require an internet connection to function.
